@@ -5,6 +5,7 @@ from iqsopenapi.marketdata  import *
 from iqsopenapi.models  import *
 from iqsopenapi.trade  import *
 from iqsopenapi.util  import *
+from iqsopenapi.external import *
 
 def run_file(strategy_file_path, config=None):
     """执行文件"""
@@ -35,8 +36,9 @@ def run_func(**kwargs):
 def __run(config, strategy_loader):
     try:
         environment = Environment(config)
-        if environment.config.logfile is not None and environment.config.logfile != '':
-            logutil.log2file(environment.config.logfile)
+        if environment.config.log:
+            logger.setLevel(environment.config.log['level'])
+            logutil.log2file(environment.config.log['file'])
 
         ucontext = StrategyContext()
 
@@ -59,6 +61,9 @@ def __run(config, strategy_loader):
         elif environment.config.run_type == 'BACKTEST':
             raise Exception('BACKTEST is not support!')
 
+        if environment.config.ext_notify:
+            user_notify = ExternalNotify(environment.config.ext_notify['address'],event_bus)
+            user_notify.init()
         from copy import copy
 
         scope = copy(iqsopenapi.models.__dict__)
@@ -72,6 +77,7 @@ def __run(config, strategy_loader):
 
         event_bus.start()
 
+        return True
     except Exception as e:
-        logger.error(e)
-
+        logger.error('init exception',e)
+        return False
