@@ -15,7 +15,7 @@ class StrategyContext(object):
         """获取策略编号"""
         if Environment.get_instance().config is None or Environment.get_instance().config.acct_info is None:
             return None
-        return Environment.get_instance().config.acct_info.strategy_id
+        return Environment.get_instance().config.acct_info['strategy_id']
    
     def subscribe(self,*args):
         """行情订阅"""
@@ -85,7 +85,15 @@ class StrategyContext(object):
         """获取历史bar"""
         (code,exchange) = self.__split_symbol(symbol)
         bar_type = self.__get_bar_type(barType)
-        data = Environment.get_instance().market_api.GetHisBar(code, exchange, bar_type, startTime, endTime)
+        start = startTime
+        end = endTime
+        if(isinstance(startTime,datetime.datetime)):
+            start = startTime.strftime("%Y%m%d%H%M%S")
+            end = endTime.strftime("%Y%m%d%H%M%S")
+        elif(isinstance(startTime,datetime.date)):
+            start = startTime.strftime("%Y%m%d")
+            end = endTime.strftime("%Y%m%d")
+        data = Environment.get_instance().market_api.GetHisBar(code, exchange, bar_type, start, end)
         if not data:
             return data
         self.__rebuild_data(*data)
@@ -94,7 +102,15 @@ class StrategyContext(object):
     def get_history_ticks(self, symbol, startTime, endTime):
         """获取订阅列表"""
         (code,exchange) = self.__split_symbol(symbol)
-        data = Environment.get_instance().market_api.GetHisTick(code, exchange, startTime, endTime)
+        start = startTime
+        end = endTime
+        if(isinstance(startTime,datetime.datetime)):
+            start = startTime.strftime("%Y%m%d%H%M%S")
+            end = endTime.strftime("%Y%m%d%H%M%S")
+        elif(isinstance(startTime,datetime.date)):
+            start = startTime.strftime("%Y%m%d")
+            end = endTime.strftime("%Y%m%d")
+        data = Environment.get_instance().market_api.GetHisTick(code, exchange, start, end)
         if not data:
             return data
         self.__rebuild_data(*data)
@@ -205,13 +221,13 @@ class StrategyContext(object):
         """获取订阅列表"""
         return Environment.get_instance().trade_api.GetAccount()
 
-    def run_by_time(self,func,time):
+    def run_by_time(self,func,time,*args):
         """定时运行函数"""
-        return Environment.get_instance().scheduler.add_task(SchedulerTask(func,time,EVENT.On_Scheduler))
+        return Environment.get_instance().scheduler.add_task(SchedulerTask(func,time,EVENT.On_Scheduler,args))
 
-    def insert_func_at_time(self,func,time):
+    def insert_func_at_time(self,func,time,*args):
         """指定时间运行函数"""
-        return Environment.get_instance().scheduler.add_task(SchedulerTask(func,time,EVENT.On_Scheduler))
+        return Environment.get_instance().scheduler.add_task(SchedulerTask(func,time,EVENT.On_Scheduler,args))
 
     def get_datetime(self):
         """获取当前时间"""
