@@ -15,7 +15,7 @@ def on_init(ctx):
 
     id = ctx.get_strategy_id()
 
-    ctx.subscribe(('IH2006.CFFEX','2m'),('jd2009.CFFEX','3m'))
+    ctx.subscribe(('rb2010.SHFE','1m'),('jd2009.CFFEX','3m'))
 
     ctx.domi_contract = ctx.get_dominant_contract(ctx.symbol)
     conInfo = ctx.get_contract(ctx.domi_contract.symbol)
@@ -46,11 +46,11 @@ def on_init(ctx):
     
     ctx.run_by_time(run_time,datetime(2020,5,21,13,58,0),'CCC','DDDDD')
 
-    #ctx.run_by_time(run_time,time(13,50,0))
+    ctx.run_by_time(run_time,time(13,50,0))
 
-    #ctx.insert_func_at_time(run_time,time(13,49,0))
+    ctx.insert_func_at_time(run_time,time(13,49,0))
 
-    ctx.insert_func_at_time(run_time,datetime(2020,5,21,13,55,0),'AAA','BBBB')
+    ctx.insert_func_at_time(run_time,datetime(2020,5,21,14,10,0),'AAA','BBBB')
 
     pass
 
@@ -127,7 +127,7 @@ def on_bar(ctx,bar):
     #    ctx.last_low = bar.low
 config = {
     "runtime":"DEBUG",
-    "run_type":"PAPER_TRADING",
+    "run_type":"LIVE_TRADING",
     "log":{
             'level':'INFO',
             'file' :r"D:\logs\test\strategy.log",
@@ -136,16 +136,16 @@ config = {
     #        "type":"websocket",
     #        "address":"ws://localhost:14002/"
     #    },
-    "acct_info":{
-            "strategy_id":"21",
-            "account":"10030"
-        }
     #"acct_info":{
-    #        "strategy_id":"1021",
-    #        "account":"060031",
-    #        "password":"Wx@123456",
-    #        "comp_counter": 96,
-    #        "broker_type":152
+    #        "strategy_id":"21",
+    #        "account":"10030"
     #    }
+    "acct_info":{
+            "strategy_id":"1021",
+            "account":"060031",
+            "password":"Wx@123456",
+            "comp_counter": 96,
+            "broker_type":152
+        }
 }
 run_func(**globals())
\ No newline at end of file
