@@ -71,12 +71,3 @@ class ResponseType(IntEnum):
 
     """周期行情"""
     KlineData = 100
-
-    """委托回报"""
-    OrderChange = 101
-
-    """成交回报"""
-    OrderExec = 102
-
-    """撤单回报"""
-    OrderCancelled = 103
