@@ -45,8 +45,15 @@ class RealTradeApi(ITradeApi):
         # 初始化user变量
         brokerType = info['broker_type']
         counterId = info['comp_counter']
-        user.AccountID = info['account']
-        user.PassWord = info['password']
+        crypt =('crypt' in info) and info['crypt']
+        aid = info['account']
+        psd = info['password']
+        if crypt:
+            user.AccountID = decrypt(aid)
+            user.PassWord = decrypt(psd)
+        else:
+            user.AccountID = aid
+            user.PassWord = psd
         user.BrokerType = brokerType
         user.CounterID = counterId
 
@@ -128,16 +135,19 @@ class RealTradeApi(ITradeApi):
         self.__wirteInfo("begin sendorder，param:{0}".format(json.dumps(params,ensure_ascii=False)))
 
         model = self.__api_core.SendOrder(order)
-        if(None == model): return None
         result = model.ErrorNo == 0
-        if(not result): return None
-
-        order.order_id = model.OrderID
-        order.status = OrderStatus.Sended
-        self.__event_bus.publish_event(order_event)
         self.__wirteInfo(f'sendorder complated，param:{json.dumps(params,ensure_ascii=False)},resp:{result}')
-        
-        return order
+
+        neworder = copy(order)
+        if(not result):
+            neworder.note = model.ErrorInfo
+            neworder.status = OrderStatus.Rejected
+        else:
+            neworder.status = OrderStatus.Sended
+            neworder.order_id = str(model.OrderID)
+        neworder_event = Event(EVENT.On_Order,data = neworder)
+        self.__event_bus.publish_event(neworder_event)
+        return neworder
 
     def CancelOrder(self,order):
         """撤单"""
@@ -145,21 +155,27 @@ class RealTradeApi(ITradeApi):
             self.__wirteInfo("invalid order can't cancel")
             return None
 
-        cancelOrder = copy(order.__dict__)
+        cancelOrder = copy(order)
         cancelOrder.status = OrderStatus.PendingCancel
         cancelOrder.strategy_id = self.__strategy_id
         cancelOrder.account_id = self.__user_info.AccountID
         order_event = Event(EVENT.On_Order,data = cancelOrder)
         self.__event_bus.publish_event(order_event)
 
-        params = {'orderId':order.order_id,'strategyId':self.__strategy_id,'tradeAccount': self.__user_info.AccountID}
+        params = {'orderId':cancelOrder.order_id,'strategyId':self.__strategy_id,'tradeAccount': self.__user_info.AccountID}
         logger.info("begin cancelorder，param:{0}".format(json.dumps(params,ensure_ascii=False)))
+        
+        model = self.__api_core.CancelOrder(cancelOrder.order_id)
+        result = model.ErrorNo == 0
 
-        result = self.__api_core.CancelOrder(orderId)
-        if(None == result): return None
-        return self.GetOrder(order.order_id)
+        newCancelOrder = self.GetOrder(order.order_id)
 
-    def GetAssetInfo(self):
+        newCancelOrder_event = Event(EVENT.On_Order,data = newCancelOrder)
+        self.__event_bus.publish_event(newCancelOrder_event)
+
+        return newCancelOrder
+
+    def GetAccount(self):
         """获取资产信息"""
         asset = self.__api_core.GetAccountFund()
         if(None ==  asset):raise Exception("获取资产信息失败")
@@ -171,7 +187,7 @@ class RealTradeApi(ITradeApi):
         orders = self.GetOrders()
         if not orders: return None
         for x in orders:
-            if x.OrderId == orderId:
+            if x.order_id == orderId:
                 return x
         return None
 
@@ -220,55 +236,59 @@ class RealTradeApi(ITradeApi):
             return
 
         logger.info(msg)
-        msg_type = MsgType(msg.get('MsgType'))
-        datas = json.dumps(msg.get('MetaData'), ensure_ascii=False)
+        msg_type = MsgType(msg.get('msgType'))
+        data = msg.get('metaData')
 
         if msg_type == MsgType.Order:
-            for item in datas:
-                order = self.__ToOrder(item)
-                if not order:
-                    return
-                order_event = Event(EVENT.On_Order,data = order)
-                self.__event_bus.publish_event(order_event)
+            order = self.__ToOrder(data)
+            if not order:
+                return
+            order_event = Event(EVENT.On_Order,data = order)
+            self.__event_bus.publish_event(order_event)
         if msg_type == MsgType.Trade:
-            for item in datas:
-                trade = self.__ToTrade(item)
-                if not trade:
-                    return
-                trade_event = Event(EVENT.On_Trade,data = trade)
-                self.__event_bus.publish_event(trade_event)
+            trade = self.__ToTrade(data)
+            if not trade:
+                return
+            trade_event = Event(EVENT.On_Trade,data = trade)
+            self.__event_bus.publish_event(trade_event)
 
-    def __ToOrder(self, data):
+    def __ToOrder(self, item):
+        data = json.loads(item)
         order = Order()
-        order.exchange = Exchange(data.get('Exchange'))
-        order.order_time = datetime.strptime(item['OrderTime'],'%Y%m%d%H%M%S')
+        order.exchange = Exchange(data['exchange'])
+        order.order_time = datetime.strptime(data['orderTime'],'%Y-%m-%d %H:%M:%S')
         #order.filled = 
-        order.note = str(data.get('ErrorMsg'))
-        order.offset = Offset(data.get('Offset'))
-        order.order_id = int(data.get('OrderId'))
-        order.side = OrderSide(data.get('OrderSide'))
-        order.order_type = OrderType(data.get('OrderType'))
-        order.price = float(data.get('Price'))
-        order.quantity = int(data.get('Quantity'))
-        order.status = OrderStatus(data.get('Status'))
-        order.symbol = str(data.get('Symbol'))
+        order.note = str(data['errorMsg'])
+        order.offset = Offset(data['offset'])
+        order.side = OrderSide.__dict__[data['orderSide']]
+        order.order_type = OrderType(data['orderType'])
+        order.price = float(data['price'])
+        order.quantity = int(data['quantity'])
+        order.status = OrderStatus(data['status'])
+        order.symbol = str(data['symbol'])
         order.strategy_id = self.__strategy_id
         order.account_id = self.__user_info.AccountID
+        order.order_id = data['orderId']
+        if ('errorNo' in data):
+            errorNo = int(data['errorNo'])
+            if(errorNo != 0 and 'errorMsg' in data):
+                order.note = data['errorMsg']
         return order
 
     def __ToTrade(self, item):
+        data = json.loads(item)
         trade = Trade()
         trade.strategy_id = self.__strategy_id
         trade.account_id = self.__user_info.AccountID
-        trade.exchange = Exchange(item.get('Exchange'))
-        trade.symbol = str(item['Symbol'])
-        trade.order_id = str(item['OrderId'])
-        trade.trade_id = str(item['TradeId'])
-        trade.side = OrderSide(item['OrderSide'])
-        trade.price = float(item['Price'])
-        trade.offset = Offset(item['Offset'])
-        trade.quantity = int(item['Filled'])
-        trade.filled_time = datetime.strptime(item['FilledTime'],'%Y%m%d%H%M%S')
+        trade.exchange = Exchange(data['exchange'])
+        trade.symbol = str(data['symbol'])
+        trade.order_id = str(data['orderId'])
+        trade.trade_id = str(data['tradeId'])
+        trade.side = OrderSide.__dict__[data['orderSide']]
+        trade.price = float(data['price'])
+        trade.offset = Offset(data['offset'])
+        trade.quantity = int(data['filled'])
+        trade.filled_time = datetime.strptime(data['filledTime'],'%Y-%m-%d %H:%M:%S')
         return trade
 
     def __wirteError(self, error):
